summaryrefslogtreecommitdiffstats
path: root/kivio/kiviopart/tools/mousetoolaction.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kivio/kiviopart/tools/mousetoolaction.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kivio/kiviopart/tools/mousetoolaction.h')
-rw-r--r--kivio/kiviopart/tools/mousetoolaction.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/kivio/kiviopart/tools/mousetoolaction.h b/kivio/kiviopart/tools/mousetoolaction.h
index 0e528578..26351ff2 100644
--- a/kivio/kiviopart/tools/mousetoolaction.h
+++ b/kivio/kiviopart/tools/mousetoolaction.h
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
*
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
- MouseToolAction(const TQString& text, const KShortcut& cut = KShortcut(), TQObject* tqparent = 0, const char* name = 0);
+ MouseToolAction(const TQString& text, const KShortcut& cut = KShortcut(), TQObject* parent = 0, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's tqparent.
* @param slot The TQT_SLOT to invoke to execute this action.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
MouseToolAction(const TQString& text, const KShortcut& cut,
- const TQObject* receiver, const char* slot, TQObject* tqparent, const char* name = 0);
+ const TQObject* receiver, const char* slot, TQObject* parent, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
MouseToolAction(const TQString& text, const TQIconSet& pix, const KShortcut& cut = KShortcut(),
- TQObject* tqparent = 0, const char* name = 0);
+ TQObject* parent = 0, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
MouseToolAction(const TQString& text, const TQString& pix, const KShortcut& cut = KShortcut(),
- TQObject* tqparent = 0, const char* name = 0);
+ TQObject* parent = 0, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's tqparent.
* @param slot The TQT_SLOT to invoke to execute this action.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
MouseToolAction(const TQString& text, const TQIconSet& pix, const KShortcut& cut,
- const TQObject* receiver, const char* slot, TQObject* tqparent, const char* name = 0);
+ const TQObject* receiver, const char* slot, TQObject* parent, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's tqparent.
* @param slot The TQT_SLOT to invoke to execute this action.
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
MouseToolAction(const TQString& text, const TQString& pix, const KShortcut& cut,
const TQObject* receiver, const char* slot,
- TQObject* tqparent, const char* name = 0);
+ TQObject* parent, const char* name = 0);
/**
* @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
- MouseToolAction(TQObject* tqparent = 0, const char* name = 0);
+ MouseToolAction(TQObject* parent = 0, const char* name = 0);
~MouseToolAction();
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's tqparent.
+ * @param receiver The SLOT's parent.
* @param slot The TQT_SLOT to invoke to execute this action.
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param slot The TQT_SLOT to invoke to execute this action.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's tqparent.
+ * @param receiver The SLOT's parent.
* @param slot The TQT_SLOT to invoke to execute this action.
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param slot The TQT_SLOT to invoke to execute this action.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's tqparent.
+ * @param receiver The SLOT's parent.
* @param slot The TQT_SLOT to invoke to execute this action.
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param slot The TQT_SLOT to invoke to execute this action.
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/
@@ -36,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
/**
- * @param tqparent This action's tqparent.
+ * @param parent This action's parent.
* @param name An internal name for this action.
*/